# aitools

Python tools for data science.

These experimental tools are in a very early stage. 

## Installation

`pip install aitools-aimfeld`

## Examples

Check out the examples in the [example notebook](examples.ipynb).
